@@ -192,13 +192,13 @@ class FlaviusOrderDecide(FlaviusBase):
                                                  delete_url='')
 
 
-class FlaviusPaymentAdd(FlaviusBase):
+class FlaviusCreditAdd(FlaviusBase):
     """
     Flaviusの支払明細を追加するAPI
     """
     def __init__(self):
-        super(FlaviusPaymentAdd, self).__init__(search_url='', create_url='', update_url=conf.FLAVIUS_API_PAYMENT_ADD,
-                                                delete_url='')
+        super(FlaviusCreditAdd, self).__init__(search_url='', create_url='', update_url=conf.FLAVIUS_API_CREDIT_ADD,
+                                               delete_url='')
 
 
 class FlaviusPaymentComplete(FlaviusBase):
