@@ -79,8 +79,8 @@ class Settings:
         return getattr(settings, "FLAVIUS_API_ORDER_DECIDE", 'api/pages.php')
 
     @property
-    def FLAVIUS_API_PAYMENT_ADD(self):
-        return getattr(settings, "FLAVIUS_API_PAYMENT_ADD", 'api/payment_add.php')
+    def FLAVIUS_API_CREDIT_ADD(self):
+        return getattr(settings, "FLAVIUS_API_PAYMENT_ADD", 'api/credit_add.php')
 
     @property
     def FLAVIUS_API_PAYMENT_COMPLETE(self):
